@@ -30,7 +30,8 @@ It is composed by three panels:
 3. Summary/Details
 """
 
-
+import logging
+logger = logging.getLogger(__name__)
 import os
 import threading
 import shlex
@@ -79,45 +80,45 @@ class ProjectWindow(ProjectBaseWindow):
 
         projMenu = menu.addSubMenu('Project')
         projMenu.addSubMenu('Browse files', 'browse',
-                            icon='fa-folder-open.gif')
+                            icon=Icon.FOLDER_OPEN)
         projMenu.addSubMenu('Remove temporary files', 'delete',
-                            icon='fa-trash-o.gif')
+                            icon=Icon.ACTION_DELETE)
         projMenu.addSubMenu('Manage project labels', 'labels',
                             icon=Icon.TAGS)
         projMenu.addSubMenu('Toggle color mode', 'color_mode',
                             shortCut="Ctrl+t", icon=Icon.ACTION_VISUALIZE)
         projMenu.addSubMenu('Select all protocols', 'select all',
-                            shortCut="Ctrl+a", icon='workflow.gif')
+                            shortCut="Ctrl+a", icon=Icon.SELECT_ALL)
         projMenu.addSubMenu('Find protocol to add', 'find protocol',
-                            shortCut="Ctrl+f", icon='binoculares.gif')
+                            shortCut="Ctrl+f", icon=Icon.FIND)
         projMenu.addSubMenu('Scipion log', 'scipion log',
-                            icon='fa-file-o.gif')
+                            icon=Icon.FILE_BW)
         projMenu.addSubMenu('Locate a protocol', 'locate protocol',
                             shortCut="Ctrl+l")
         projMenu.addSubMenu('Add a protocol', 'find protocol',
                             shortCut="Ctrl+f")
         projMenu.addSubMenu('', '')  # add separator
         projMenu.addSubMenu('Import workflow', 'load_workflow',
-                            icon='fa-download.gif')
+                            icon=Icon.DOWNLOAD)
         projMenu.addSubMenu('Search workflow', 'search_workflow',
-                            icon='fa-search.gif')
+                            icon=Icon.ACTION_SEARCH)
         if pw.Config.debugOn():
             projMenu.addSubMenu('Export tree graph', 'export_tree')
         projMenu.addSubMenu('', '')  # add separator
         projMenu.addSubMenu('Debug Mode', 'debug mode',
-                            shortCut="Ctrl+d", icon='debug.gif')
+                            shortCut="Ctrl+d", icon=Icon.DEBUG)
         projMenu.addSubMenu('', '')  # add separator
-        projMenu.addSubMenu('Notes', 'notes', icon='fa-pencil.gif')
+        projMenu.addSubMenu('Notes', 'notes', icon=Icon.ACTION_EDIT)
         projMenu.addSubMenu('', '')  # add separator
-        projMenu.addSubMenu('Exit', 'exit', icon='fa-sign-out.gif')
+        projMenu.addSubMenu('Exit', 'exit', icon=Icon.ACTION_OUT)
 
         helpMenu = menu.addSubMenu('Help')
         helpMenu.addSubMenu('Online help', 'online_help',
-                            icon='fa-external-link.gif')
+                            icon=Icon.ACTION_EXPORT)
         helpMenu.addSubMenu('About', 'about',
-                            icon='fa-question-circle.gif')
+                            icon=Icon.ACTION_HELP)
         helpMenu.addSubMenu('Contact support', 'contact_us',
-                            icon='fa-question-circle.gif')
+                            icon=Icon.ACTION_HELP)
 
         self.menuCfg = menu
 
@@ -156,7 +157,7 @@ class ProjectWindow(ProjectBaseWindow):
             if not self.project.openedAsReadOnly():
                 self.saveSettings()
         except Exception as ex:
-            print("%s %s" % (Message.NO_SAVE_SETTINGS, str(ex)))
+            logger.info("%s %s" % (Message.NO_SAVE_SETTINGS, str(ex)))
         ProjectBaseWindow._onClosing(self)
      
     def loadProject(self):
@@ -168,7 +169,7 @@ class ProjectWindow(ProjectBaseWindow):
         if os.path.exists(settingsPath):
             self.settings = proj.getSettings()
         else:
-            print('Warning: settings.sqlite not found! '
+            logger.info('Warning: settings.sqlite not found! '
                   'Creating default settings..')
             self.settings = proj.createSettings()
 
@@ -262,9 +263,9 @@ class ProjectWindow(ProjectBaseWindow):
             openTextFileEditor(dotFile.name)
 
         if useId:
-            print("\nexport SCIPION_TREE_NAME=1 # to use names instead of ids")
+            logger.info("\nexport SCIPION_TREE_NAME=1 # to use names instead of ids")
         else:
-            print("\nexport SCIPION_TREE_NAME=0 # to use ids instead of names")
+            logger.info("\nexport SCIPION_TREE_NAME=0 # to use ids instead of names")
 
     def onManageProjectLabels(self):
         self.manageLabels()
@@ -327,7 +328,7 @@ class ProjectWindow(ProjectBaseWindow):
             func = self._OBJECT_COMMANDS.get(cmd, None)
 
             if func is None:
-                print("Error, command '%s' not found. " % cmd)
+                logger.info("Error, command '%s' not found. " % cmd)
             else:
                 def myfunc():
                     func(inputObj, objId)
@@ -335,8 +336,7 @@ class ProjectWindow(ProjectBaseWindow):
                 self.enqueue(myfunc)
 
         except Exception as ex:
-            print("There was an error executing object command !!!:")
-            print(ex)
+            logger.error("There was an error executing object command !!!:", exc_info=ex)
     
     def recalculateCTF(self, inputObjId, sqliteFile):
         """ Load the project and launch the protocol to
@@ -375,20 +375,21 @@ class ProjectManagerWindow(ProjectBaseWindow):
         menu = MenuConfig()
 
         fileMenu = menu.addSubMenu('File')
-        fileMenu.addSubMenu('Browse files', 'browse', icon='fa-folder-open.gif')
-        fileMenu.addSubMenu('Exit', 'exit', icon='fa-sign-out.gif')
+        fileMenu.addSubMenu('Browse files', 'browse', icon=Icon.FOLDER_OPEN)
+        fileMenu.addSubMenu('Exit', 'exit', icon=Icon.ACTION_OUT)
 
         confMenu = menu.addSubMenu('Configuration')
         if os.path.exists(pw.Config.SCIPION_CONFIG):
             confMenu.addSubMenu('General', 'general')
         confMenu.addSubMenu('Hosts', 'hosts')
-        confMenu.addSubMenu('Protocols', 'protocols')
+        if os.path.exists(pw.Config.SCIPION_PROTOCOLS):
+            confMenu.addSubMenu('Protocols', 'protocols')
         if os.path.exists(pw.Config.SCIPION_LOCAL_CONFIG):
             confMenu.addSubMenu('User', 'user')
 
         helpMenu = menu.addSubMenu('Help')
-        helpMenu.addSubMenu('Online help', 'online_help', icon='fa-external-link.gif')
-        helpMenu.addSubMenu('About', 'about', icon='fa-question-circle.gif')
+        helpMenu.addSubMenu('Online help', 'online_help', icon=Icon.ACTION_EXPORT)
+        helpMenu.addSubMenu('About', 'about', icon=Icon.ACTION_HELP)
 
         self.menuCfg = menu
         self.generalCfg = settings.getConfig()
@@ -439,12 +440,6 @@ class ProjectManagerWindow(ProjectBaseWindow):
     def onUser():
         ProjectManagerWindow._openConfigFile(pw.Config.SCIPION_LOCAL_CONFIG)
 
-    # Moved to scipion-app
-    # def onPlugins(self):
-    #     # Config -> Plugins
-    #     PluginManager("Plugin Manager", self, pw.Config.SCIPION_USER_DATA,
-    #                   selectButton=None).show()
-
 
 class ProjectTCPServer(socketserver.ThreadingMixIn, socketserver.TCPServer):
     pass
@@ -460,6 +455,8 @@ class ProjectTCPRequestHandler(socketserver.BaseRequestHandler):
             msg = msg.decode()
             tokens = shlex.split(msg)
             if msg.startswith('run protocol'):
+                
+                logger.debug("run protocol messaged arrived: %s" % msg)
                 protocolName = tokens[2]
                 protocolClass = pw.Config.getDomain().getProtocols()[protocolName]
                 # Create the new protocol instance and set the input values
