@@ -69,7 +69,6 @@ DEFAULT_BOX_COLOR = '#f8f8f8'
 
 
 RUNS_TREE = Icon.RUNS_TREE
-RUNS_LIST = Icon.RUNS_LIST
 
 VIEW_LIST = 0
 VIEW_TREE = 1
@@ -295,7 +294,7 @@ class ProtocolsView(tk.Frame):
         # Just configure the provider, later below, in updateSelection, it will be
         # provided with the protocols.
         provider = RunIOTreeProvider(self, None,
-                                     self.project.mapper)
+                                     self.project.mapper, self.info)
 
         rowheight = pwgui.getDefaultFont().metrics()['linespace']
         self.style.configure("NoBorder.Treeview", background='white',
@@ -614,17 +613,19 @@ class ProtocolsView(tk.Frame):
             t.tag_bind(tag, TK.ENTER, self._protocolItemClick)
 
         # Protocol nodes
-        configureTag(ProtocolTreeConfig.TAG_PROTOCOL, 'python_file.gif')
+        configureTag(ProtocolTreeConfig.TAG_PROTOCOL, Icon.PRODUCTION)
         # New protocols
-        configureTag(ProtocolTreeConfig.TAG_PROTOCOL_NEW, 'new.gif')
+        configureTag(ProtocolTreeConfig.TAG_PROTOCOL_NEW, Icon.NEW)
         # Beta protocols
-        configureTag(ProtocolTreeConfig.TAG_PROTOCOL_BETA, 'beta.gif')
+        configureTag(ProtocolTreeConfig.TAG_PROTOCOL_BETA, Icon.BETA)
         # Disable protocols (not installed) are allowed to be added.
         configureTag(ProtocolTreeConfig.TAG_PROTOCOL_DISABLED,
-                     'prot_disabled.gif')
-
-        t.tag_configure('protocol_base', image=self.getImage('class_obj.gif'))
-        t.tag_configure('protocol_group', image=self.getImage('class_obj.gif'))
+                     Icon.PROT_DISABLED)
+        # Updates protocols
+        configureTag(ProtocolTreeConfig.TAG_PROTOCOL_UPDATED,
+                     Icon.UPDATED)
+        t.tag_configure('protocol_base', image=self.getImage(Icon.GROUP))
+        t.tag_configure('protocol_group', image=self.getImage(Icon.GROUP))
         t.tag_configure('section', font=self.windows.fontBold)
         return t
 
@@ -730,18 +731,7 @@ class ProtocolsView(tk.Frame):
 
             # I think this mode is deprecated
             if obj.value is not None and tag == 'protocol_base':
-                print('protocol_base tags are deprecated')
-                # if prot is not None:
-                #     tree.item(item, image=self.getImage('class_obj.gif'))
-                #
-                #     for k, v in emProtocolsDict.items():
-                #         if (k not in subclassedDict and v is not prot and
-                #            issubclass(v, prot)):
-                #             key = '%s.%s' % (item, k)
-                #             t = v.getClassLabel()
-                #             tree.insert(item, 'end', key, text=t, tags='protocol')
-                # else:
-                #     raise Exception("Class '%s' not found" % obj.value.get())
+                logger.warning('protocol_base tags are deprecated')
         else:
             key = prefix
 
@@ -1469,7 +1459,7 @@ class ProtocolsView(tk.Frame):
             prot = self.getSelectedProtocol()
 
             if prot:
-                provider = RunIOTreeProvider(self, prot, self.project.mapper)
+                provider = RunIOTreeProvider(self, prot, self.project.mapper, self.info)
                 self.infoTree.setProvider(provider)
                 self.infoTree.grid(row=0, column=0, sticky='news')
                 self.infoTree.update_idletasks()
@@ -1673,7 +1663,7 @@ class ProtocolsView(tk.Frame):
                 pwgui.dialog.MessageDialog(
                     self, Message.TITLE_STOPPED_WORKFLOW_FAILED,
                     Message.TITLE_STOPPED_WORKFLOW_FAILED + ' with: ' + msg,
-                    'fa-times-circle_alert.gif')
+                    Icon.ERROR)
 
     def _resetWorkFlow(self, action):
 
@@ -1693,7 +1683,7 @@ class ProtocolsView(tk.Frame):
             pwgui.dialog.MessageDialog(
                 self, Message.TITLE_RESETED_WORKFLOW_FAILED,
                 Message.TITLE_RESETED_WORKFLOW_FAILED + ' with: ' + msg,
-                'fa-times-circle_alert.gif')
+                Icon.ERROR)
 
     def _launchWorkFlow(self, action):
         """
@@ -1714,7 +1704,7 @@ class ProtocolsView(tk.Frame):
                 self, Message.TITLE_LAUNCHED_WORKFLOW_FAILED_FORM,
                 Message.TITLE_LAUNCHED_WORKFLOW_FAILED + "\n" +
                 Message.TITLE_ACTIVE_PROTOCOLS + "\n" + msg,
-                'fa-times-circle_alert.gif')
+                Icon.ERROR)
 
         elif action == ACTION_RESTART_WORKFLOW:
             if pwgui.dialog.askYesNo(Message.TITLE_RESTART_WORKFLOW_FORM,
@@ -1737,7 +1727,7 @@ class ProtocolsView(tk.Frame):
             pwgui.dialog.MessageDialog(
                 self, Message.TITLE_LAUNCHED_WORKFLOW_FAILED_FORM,
                 Message.TITLE_LAUNCHED_WORKFLOW_FAILED + "\n" + msg,
-                'fa-times-circle_alert.gif')
+                Icon.ERROR)
         self.refreshRuns()
 
     def _selectLabels(self):
@@ -1809,7 +1799,7 @@ class ProtocolsView(tk.Frame):
                                           "*%s* already exists, do you want "
                                           "to overwrite it?" % filename)):
                     self.project.exportProtocols(protocols, filename)
-                    self.windows.showInfo("Workflow successfully saved to '%s' "
+                    logger.info("Workflow successfully saved to '%s' "
                                           % filename)
                 else:  # try again
                     self._exportProtocols(defaultPath=browser.getCurrentDir(),
