@@ -41,11 +41,19 @@ from pyworkflow.viewer import DESKTOP_TKINTER
 class RunIOTreeProvider(pwgui.tree.TreeProvider):
     """Create the tree elements from a Protocol Run input/output children"""
 
-    def __init__(self, parent, protocol, mapper):
-        # TreeProvider.__init__(self)
+    def __init__(self, parent, protocol, mapper, loggerCallback):
+        """
+
+        :param parent:
+        :param protocol:
+        :param mapper:
+        :param loggerCallback: method to call to log events in the gui.
+        """
+
         self.parent = parent
         self.protocol = protocol
         self.mapper = mapper
+        self._loggerCallback = loggerCallback
 
     @staticmethod
     def getColumns():
@@ -123,6 +131,13 @@ class RunIOTreeProvider(pwgui.tree.TreeProvider):
             isPointer = False
         actions = []
 
+        # If viewers not loaded yet (firstime)
+        domain = Config.getDomain()
+
+        if not domain.viewersLoaded():
+            self._loggerCallback("Discovering viewers for the first time across all the plugins.")
+
+
         viewers = Config.getDomain().findViewers(obj.getClassName(), DESKTOP_TKINTER)
 
         def viewerCallback(viewer):
@@ -259,10 +274,11 @@ class ProtocolTreeConfig:
     TAG_PROTOCOL_GROUP = 'protocol_group'
     TAG_PROTOCOL_BETA = 'protocol_beta'
     TAG_PROTOCOL_NEW = 'protocol_new'
+    TAG_PROTOCOL_UPDATED = 'protocol_updated'
     PLUGIN_CONFIG_PROTOCOLS = 'protocols.conf'
 
     @classmethod
-    def getProtocolTag(cls, isInstalled, isBeta=False, isNew=False):
+    def getProtocolTag(cls, isInstalled, isBeta=False, isNew=False, isUpdated=False):
         """ Return the proper tag depending if the protocol is installed or not.
         """
         if isInstalled:
@@ -270,6 +286,8 @@ class ProtocolTreeConfig:
                 return cls.TAG_PROTOCOL_BETA
             elif isNew:
                 return cls.TAG_PROTOCOL_NEW
+            elif isUpdated:
+                return cls.TAG_PROTOCOL_UPDATED
             return cls.TAG_PROTOCOL
         else:
             return cls.TAG_PROTOCOL_DISABLED
@@ -378,12 +396,14 @@ class ProtocolTreeConfig:
         # check if it is disabled
         protClassName = item["value"]
         protClass = Config.getDomain().getProtocols().get(protClassName)
-        icon = 'python_file.gif'
+        icon = Icon.PRODUCTION
         if protClass is not None:
             if protClass.isBeta():
-                icon = "beta.gif"
+                icon = Icon.BETA
             elif protClass.isNew():
-                icon = "new.gif"
+                icon = Icon.NEW
+            elif protClass.isUpdated():
+                icon = Icon.UPDATED
         item['icon'] = icon
         return False if protClass is None else not protClass.isDisabled()
 
@@ -416,7 +436,7 @@ class ProtocolTreeConfig:
                     packages[packageName] = packageMenu
 
                 # Add the protocol
-                tag = cls.getProtocolTag(v.isInstalled(), v.isBeta(), v.isNew())
+                tag = cls.getProtocolTag(v.isInstalled(), v.isBeta(), v.isNew(), v.isUpdated())
 
                 protLine = {"tag": tag, "value": k,
                             "text": v.getClassLabel(prependPackageName=False)}
@@ -531,7 +551,7 @@ class ProtocolConfig(MenuConfig):
         if 'icon' not in args:
             tag = args.get('tag', None)
             if tag == 'protocol_base':
-                args['icon'] = 'class_obj.gif'
+                args['icon'] = Icon.GROUP
 
         args['shortCut'] = shortCut
         return MenuConfig.addSubMenu(self, text, value, **args)
