@@ -27,6 +27,11 @@
 # *
 # **************************************************************************
 import logging
+
+from .protocol import Protocol
+from .viewer import Viewer
+from .wizard import Wizard
+
 logger = logging.getLogger(__name__)
 import glob
 import os
@@ -55,11 +60,11 @@ class Domain:
     """
 
     # The following classes should be defined in subclasses of Domain
-    _name = None
-    _protocolClass = None
+    _name = __name__
+    _protocolClass = Protocol
     _objectClass = pwobj.Object
-    _viewerClass = None
-    _wizardClass = None
+    _viewerClass = Viewer
+    _wizardClass = Wizard
     _baseClasses = {}  # Update this with the base classes of the Domain
 
     # Dictionaries to store different type of objects
@@ -248,6 +253,11 @@ class Domain:
         """ Return all EMObject subclasses from all plugins for this domain."""
         return cls.__getSubclasses('objects', cls._objectClass)
 
+    @classmethod
+    def viewersLoaded(cls):
+        """ Returns true if viewers have been already discovered"""
+        return len(cls._viewers) != 0
+
     @classmethod
     def getViewers(cls):
         """ Return all Viewer subclasses from all plugins for this domain."""
@@ -534,7 +544,7 @@ class Plugin:
     @classmethod
     def getCondaActivationCmd(cls):
         if cls._condaActivationCmd is None:
-            condaActivationCmd = os.environ.get(CONDA_ACTIVATION_CMD_VAR, "")
+            condaActivationCmd = pw.Config.CONDA_ACTIVATION_CMD
             if not condaActivationCmd:
                 logger.info("WARNING!!_condaActivationCmd: %s variable not defined. "
                       "Relying on conda being in the PATH" % CONDA_ACTIVATION_CMD_VAR)
