@@ -661,9 +661,6 @@ class Project(object):
             label = protocol.getObjLabel()
             comment = protocol.getObjComment()
 
-            if checkPid:
-                self.checkPid(protocol)
-
             if skipUpdatedProtocols:
                 # If we are already updated, comparing timestamps
                 if pwprot.isProtocolUpToDate(protocol):
@@ -699,10 +696,14 @@ class Project(object):
             protocol.setObjLabel(label)
             protocol.setObjComment(comment)
             # Use the run.db timestamp instead of the system TS to prevent
-            # possible inconsistencies
-            # protocol.lastUpdateTimeStamp.set(datetime.datetime.now())
+            # possible inconsistencies.
             protocol.lastUpdateTimeStamp.set(lastUpdateTime)
 
+            # Check pid at the end, once updated
+            if checkPid:
+                self.checkPid(protocol)
+
+
             self.mapper.store(protocol)
 
             # Close DB connections
@@ -1154,7 +1155,7 @@ class Project(object):
             protClass = emProtocols.get(protClassName, None)
 
             if protClass is None:
-                logger.error("Protocol with class name '%s' not found. Are you missing it's plugin?." % protClassName)
+                logger.error("Protocol with class name '%s' not found. Are you missing its plugin?." % protClassName)
             else:
                 protLabel = protDict.get('object.label', None)
                 prot = self.newProtocol(protClass,
@@ -1393,6 +1394,9 @@ class Project(object):
         from pyworkflow.protocol.launch import _runsLocally
         pid = protocol.getPid()
 
+        if pid == 0:
+            return
+
         # Include running and scheduling ones
         # Exclude interactive protocols
         # NOTE: This may be happening even with successfully finished protocols
