@@ -86,9 +86,11 @@ def schedule(protocol, initialSleepTime=0, wait=False):
     run yet. Right now it only make sense to schedule jobs locally.
     """
     cmd = '%s %s' % (pw.PYTHON, pw.getScheduleScript())
-    cmd += ' "%s" "%s" %s --initial_sleep %s' % (protocol.getProject().path,
+    cmd += ' "%s" "%s" %s "%s" --initial_sleep %s' % (protocol.getProject().path,
                               protocol.getDbPath(),
-                              protocol.strId(), initialSleepTime)
+                              protocol.strId(),
+                              protocol.getScheduleLog(),
+                              initialSleepTime)
     jobId = _run(cmd, wait)
     protocol.setJobId(jobId)
 
@@ -119,13 +121,42 @@ def _getAppsProgram(prog):
 
 
 def _launchLocal(protocol, wait, stdin=None, stdout=None, stderr=None):
-    # Check first if we need to launch with MPI or not
-    command = ('%s %s "%s" "%s" %s'
-               % (pw.PYTHON, pw.join(pw.APPS, 'pw_protocol_run.py'),
-                  protocol.getProject().path, protocol.getDbPath(),
-                  protocol.strId()))
+    """
+
+    :param protocol: Protocol to launch
+    :param wait: Pass true if you want to wait for the process to finish
+    :param stdin: stdin object to direct stdin to
+    :param stdout: stdout object to send process stdout
+    :param stderr: stderr object to send process stderr
+    :return: PID of queue's JOBID
+    """
+
+    command = '{python} {prot_run} "{project_path}" "{db_path}" {prot_id} "{stdout_log}" "{stderr_log}"'.format(
+        python=pw.PYTHON,
+        prot_run=pw.join(pw.APPS, 'pw_protocol_run.py'),
+        project_path=protocol.getProject().path,
+        db_path=protocol.getDbPath(),
+        prot_id=protocol.strId(),
+        # We make them absolute in case working dir is not passed to the node when running through a queue.
+        # The reason is that since 3.0.27, the first thing that is affected by the current working dir is the
+        # creation of the logs. Before event than loading the project, which was and is setting the working dir to
+        # the project path. IMPORTANT: This assumes the paths before the queue and after the queue (nodes) are the same
+        # Which I think is safe since we are passing here "project_path" that is absolute.
+        stdout_log=os.path.abspath(protocol.getStdoutLog()),
+        stderr_log=os.path.abspath(protocol.getStderrLog())
+    )
+
+    #command = ('%s %s "%s" "%s" %s "%s" "%s"'
+    #           % (pw.PYTHON, pw.join(pw.APPS, 'pw_protocol_run.py'),
+    #              protocol.getProject().path, protocol.getDbPath(),
+    #              protocol.strId()))
+
     hostConfig = protocol.getHostConfig()
     useQueue = protocol.useQueue()
+
+    # Empty PID: 0
+    protocol.setPid(0)
+
     # Check if need to submit to queue    
     if useQueue and (protocol.getSubmitDict()["QUEUE_FOR_JOBS"] == "N"):
         submitDict = dict(hostConfig.getQueuesDefault())
