@@ -25,7 +25,7 @@
 This modules contains classes required for the workflow
 execution and tracking like: Step and Protocol
 """
-import sys
+import sys, os
 import json
 import threading
 import time
@@ -41,7 +41,6 @@ from .constants import *
 from .params import Form
 from ..utils import getFileSize
 
-SCHEDULE_LOG = 'schedule.log'
 
 import  logging
 # Get the root logger
@@ -355,6 +354,7 @@ class Protocol(Step):
         Step.__init__(self, **kwargs)
         self._size = None
         self._steps = []  # List of steps that will be executed
+        self._newSteps = False  # Boolean to annotate when there are new steps added to the above list. And need persistence.
         # All generated filePaths should be inside workingDir
         self.workingDir = String(kwargs.get('workingDir', '.'))
         self.mapper = kwargs.get('mapper', None)
@@ -541,13 +541,15 @@ class Protocol(Step):
     def isNew(cls):
         if cls._devStatus == pw.NEW:
             return True
-        elif cls._devStatus == pw.PROD:
-            return cls._lastUpdateVersion not in pw.OLD_VERSIONS
 
     @classmethod
     def isBeta(cls):
         return cls._devStatus == pw.BETA
 
+    @classmethod
+    def isUpdated(cls):
+        return cls._devStatus == pw.UPDATED
+
     def getDefinition(self):
         """ Access the protocol definition. """
         return self._definition
@@ -735,8 +737,12 @@ class Protocol(Step):
                             logger.debug("Pointer found in output: %s.%s (%s)" % (output, k, attr))
                             prot = attr.getObjValue()
                             if prot is not None:
-                                protocolIds.append(prot.getObjId())
-
+                                if isinstance(prot, Protocol):
+                                    protocolIds.append(prot.getObjId())
+                                else:
+                                    logger.warning(f"We have found that {output}.{key} points to {attr} "
+                                                   f"and is a direct pointer. Direct pointers are less reliable "
+                                                   f"in streaming scenarios. Developers should avoid them.")
             protocolIds.append(protocol.getObjId())
 
         return protocolIds
@@ -990,6 +996,7 @@ class Protocol(Step):
             step.addPrerequisites(*prerequisites)
 
         self._steps.append(step)
+        self._newSteps = True
         # Setup and return step index
         step.setIndex(len(self._steps))
 
@@ -1484,8 +1491,6 @@ class Protocol(Step):
         to run should exists.
         """
         try:
-            LoggingConfigurator.setUpProtocolRunLogging(self.getLogPaths()[0], self.getLogPaths()[1] )
-
             self.info(pwutils.greenStr('RUNNING PROTOCOL -----------------'))
             self.info("Protocol starts", extra=getExtraLogInfo("PROTOCOL", STATUS.START,
                                                                project_name=self.getProject().getName(),
@@ -1502,6 +1507,7 @@ class Protocol(Step):
             self.info('plugin: %s' % self.getClassPackageName())
             if hasattr(self.getClassPackage(), "__version__"):
                 self.info('plugin v: %s' % self.getClassPackage().__version__)
+            self.info('plugin binary v: %s' % self.getClassPackage().Plugin.getActiveVersion())
             self.info('currentDir: %s' % os.getcwd())
             self.info('workingDir: %s' % self.workingDir)
             self.info('runMode: %s' % MODE_CHOICES[self.runMode.get()])
@@ -1546,11 +1552,16 @@ class Protocol(Step):
 
 
     def getLogPaths(self):
-        return list(map(self._getLogsPath,
-                        ['run.stdout', 'run.stderr', SCHEDULE_LOG]))
+        return [self.getStdoutLog(),self.getStderrLog() , self.getScheduleLog()]
+
+    def getStdoutLog(self):
+        return self._getLogsPath("run.stdout")
+
+    def getStderrLog(self):
+        return self._getLogsPath('run.stderr')
 
     def getScheduleLog(self):
-        return self._getLogsPath(SCHEDULE_LOG)
+        return self._getLogsPath('schedule.log')
 
     def getSteps(self):
         """ Return the steps.sqlite file under logs directory. """
@@ -1883,6 +1894,7 @@ class Protocol(Step):
         self._storeSteps()
         self._numberOfSteps.set(len(self._steps))
         self._store(self._numberOfSteps)
+        self._newSteps = False
 
     def getStatusMessage(self):
         """ Return the status string and if running the steps done.
@@ -2099,15 +2111,18 @@ class Protocol(Step):
         try:
 
             journal = cite.get("journal", cite.get("booktitle", ""))
-            doi = cite.get("doi", "")
+            doi = cite.get("doi", "").strip()
+            url = cite.get("url", "").strip()
             # Get the first author surname
             if useKeyLabel:
                 label = cite['ID']
             else:
                 label = cite['author'].split(' and ')[0].split(',')[0].strip()
                 label += ' et al., %s, %s' % (journal, cite['year'])
-            if len(doi.strip()) > 0:
-                text = '[[%s][%s]] ' % (doi.strip(), label)
+            if len(doi) > 0:
+                text = '[[%s][%s]] ' % (doi, label)
+            elif len(url) > 0:
+                text = '[[%s][%s]] ' % (url, label)
             else:
                 text = label.strip()
             return text
@@ -2158,11 +2173,11 @@ class Protocol(Step):
         """ Return a citation message to provide some information to users. """
         citations = list(self.getCitations().values())
         if citations:
-            citations.insert(0, '*References:* ')
+            citations.insert(0, '*Protocol references:* ')
 
         packageCitations = self.getPackageCitations().values()
         if packageCitations:
-            citations.append('*Package References:*')
+            citations.append('*Package references:*')
             citations += packageCitations
         if not citations:
             return ['No references provided']
@@ -2451,3 +2466,47 @@ def isProtocolUpToDate(protocol):
 
 class ProtImportBase(Protocol):
     """ Base Import protocol"""
+
+class ProtStreamingBase(Protocol):
+    """ Base protocol to implement streaming protocols.
+    stepsGeneratorStep should be implemented (see its description) and output
+    should be created at the end of the processing Steps created by the stepsGeneratorStep.
+    To avoid concurrency error, when creating the output, do it in a with self._lock: block.
+    Minimum number of threads is 3 and should run in parallel mode.
+    """
+
+    def __init__(self, **kwargs):
+
+        super().__init__()
+        self.stepsExecutionMode = STEPS_PARALLEL
+    def _insertAllSteps(self):
+        # Insert the step that generates the steps
+        self._insertFunctionStep(self.stepsGeneratorStep)
+
+    def _stepsCheck(self):
+
+        # Just store steps created in checkNewInputStep
+        if self._newSteps:
+            self.updateSteps()
+
+    def stepsGeneratorStep(self):
+        """
+        This step should be implemented by any streaming protocol.
+        It should check its input and when ready conditions are met
+        call the self._insertFunctionStep method.
+
+        :return: None
+        """
+        pass
+
+    def _validateThreads(self, messages:list):
+
+        if self.numberOfThreads.get() < 3:
+            messages.append("At least 3 threads are needed for running this protocol. 1 for the core process, "
+                            "1 for the 'step-generator step' and one more for the actual processing" )
+    def _validate(self):
+        """ If you want to implement a validate method do it but call _validateThreads or validate threads value."""
+        errors = []
+        self._validateThreads(errors)
+
+        return errors
\ No newline at end of file
