@@ -35,6 +35,8 @@ from pyworkflow.mapper.sqlite import ID, CREATION
 from ..objects import (Complex, MockSetOfImages, MockImage, MockObject,
                        MockAcquisition, MockMicrograph)
 
+IMAGES_STK = "images.stk"
+
 NUMERIC_ATRIBUTE_NAME = "1"
 
 NUMERIC_ATTRIBUTE_VALUE = "numeric_attribute"
@@ -139,6 +141,19 @@ class TestObject(pwtests.BaseTest):
         s.set(now)
         self.assertEqual(now, s.datetime())
 
+        # Ranges and values
+        s2.set("1 2 3 4")
+        self.assertEqual(s2.getListFromValues(caster=float), [1.,2.,3.,4.])
+        self.assertEqual(s2.getListFromRange(), [1, 2, 3, 4])
+
+        # Values ...
+        s2.set("2x4, 4, 7")
+        self.assertEqual(s2.getListFromValues(), [4, 4, 4, 7])
+
+        # Ranges
+        s2.set("2-8, 1-2, 7")
+        self.assertEqual(s2.getListFromRange(), [2, 3, 4, 5, 6, 7, 8, 1, 2, 7])
+
     def test_Pointer(self):
         c = Complex.createComplex()
         p = pwobj.Pointer()
@@ -147,7 +162,7 @@ class TestObject(pwtests.BaseTest):
         c.Name = pwobj.String('Paquito')
 
         self.assertEqual(p.get(), 'Paquito')
-        stackFn = "images.stk"
+        stackFn = IMAGES_STK
         mrcsFn = "images.mrcs"
         fn = self.getOutputPath('test_images.sqlite')
         imgSet = MockSetOfImages(filename=fn)
@@ -238,11 +253,8 @@ class TestObject(pwtests.BaseTest):
         ptr5 = pwobj.Pointer(value=o2, extended=NUMERIC_ATRIBUTE_NAME)
         self.assertEqual(NUMERIC_ATTRIBUTE_VALUE, ptr5.get())
 
-
-
-
     def test_Sets(self):
-        stackFn = "images.stk"
+        stackFn = IMAGES_STK
         fn = self.getOutputPath('test_images2.sqlite')
 
         imgSet = MockSetOfImages(filename=fn)
